<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\DB;

use Inertia\Inertia;
use Inertia\Response;
use App\Models\Product;
use App\Models\Cart;
use App\Models\User;
use App\Models\Order;
use App\Models\Address;

class CheckoutController extends Controller
{
    public function checkout(Request $request): Response {
        $userid = $request->user()->id;
        $user = User::find($userid);
        $addresses = $user->addresses;

        $cartItems = DB::table('cart')
            ->join('products', 'cart.product_id', '=', 'products.id')
            ->where('user_id', $userid)
            ->select('cart.*', 'cart.id as cart_id', 'cart.quantity as cart_qty', 'products.*')
            ->get();
        return Inertia::render('Checkout', [
            'cart' => $cartItems,
            'addresses' => $addresses,
        ]);
    }

    public function saveOrder(Request $request) {
        $userid = $request->user()->id;

        if($userid) {
            $cartItems = DB::table('cart')
            ->join('products', 'cart.product_id', '=', 'products.id')
            ->where('user_id', $userid)
            ->select('cart.*', 'cart.id as cart_id', 'cart.quantity as cart_qty', 'products.*')
            ->get();
            $productsList = array();
            if($cartItems) {
                $products = array();
                foreach($cartItems as $cart) {
                    $products['id'] = $cart->id;
                    $products['qty'] = $cart->cart_qty;
                    $products['price'] = $cart->price;

                    $productsList[] = $products;
                }
            }

            $order = Order::create([
                'user_id' => $userid,
                'products_data' => serialize($productsList),
                'price' => $request->price,
                'shipping_tracking' => $request->shipping_tracking,
                'total_price' => $request->total_price,
                'comment' => $request->comment,
                'customer_po' => $request->customer_po,
                'tax' => $request->tax,
                'shipping_id' => $request->shipping_id,
                'shipping_price' => $request->shipping_price,
                'addressID' => $request->addressID,
            ]);

            Cart::where('user_id', $userid)->truncate();

            return redirect()->route('order.detail', ['id' => $order->id]);
        }
    }

    public function saveAddress(Request $request) {
        $userid = $request->user()->id;
        $user = User::find($userid);

        $user->addresses()->create([
            'name' => 'Drop Ship Address',
            'user_id' => $userid,
            'company' => $request->company,
            'contact' => $request->contact,
            'phone' => $request->phone,
            'fax' => $request->fax,
            'address1' => $request->address1,
            'address2' => $request->address2,
            'city' => $request->city,
            'state' => $request->state,
            'zip' => $request->zip,
            'country' => $request->country,
        ]);

        return Redirect::back();
    }

    public function orderDetail($id): Response
    {
        if(isset($id) && !empty($id)) {
            $orderDetail = Order::find($id);

            if($orderDetail) {
                $productsData = $orderDetail->products_data;
                $products = unserialize($productsData);
                $productsDetails = array();
                if($products) {
                    foreach ($products as $product) {
                        $productsDetails[] = Product::find($product['id']);
                    }
                }

                $userid = $orderDetail->user_id;
                $addressID = $orderDetail->addressID;
                if($addressID != 'primary') {
                    $addressDetails = Address::find($addressID);
                }
                else {
                    $addressDetails = User::find($userid);
                }

                return Inertia::render('Order', [
                    'order' => $orderDetail,
                    'productsDetails' => $productsDetails,
                    'products' => $products,
                    'address' => $addressDetails,
                ]);
            }
        }
    }
}
